from setuptools import setup, find_packages
setup(
    name="kangface",
    version="0.0.1",
    author="HuDongkang",
    author_email="2376699679@qq.com",
    description="This project provides an easy way to recognize faces using AI",
    # 项目主页
    url="https://gitee.com/hudongkang/p9-project/kangface",
    # 你要安装的包，通过 setuptools.find_packages 找到当前目录下有哪些包
    packages=find_packages()
)